Documentation
¶
Overview ¶
Package cli provides a simple way to register program flags, options, and environment variables.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CLI ¶
type CLI struct {
// contains filtered or unexported fields
}
func New ¶
func New( name string, description string, usage string, version string, options []Opt, arguments []Arg, ) *CLI
New registers environment variables and program flags according to the options and handles creation of a usage func. Make sure to call cli.ReadEnv to read the environment variables and Parse to parse the program flags.
type Opt ¶
type Opt struct {
// Name of the program flag. If empty, no program flag is registered.
Name string
// Desc description of option.
Desc string
// Env is an optional environment variable to register.
Env string
// Ptr is a pointer to the value to set. Supported types are string, int,
// bool, and flag.Value. If the value being pointed to is non-zero it will be
// used as the default value for the option.
Ptr any
// DocumentationOnly is set to document environment variables which are not
// parsed through this package. It is permitted only on Opts where both Name
// and Ptr fields are unspecified.
DocumentationOnly bool
// TypeName is an optional hint to the user what the type of the option is.
// If unset the type name pointed-to by Ptr will be used.
TypeName string
// contains filtered or unexported fields
}
Opt is a program option.
Click to show internal directories.
Click to hide internal directories.